/*
 *
 * langpacks-install - Tool to get auto installed langpacks on session startup
 * Copyright (C) 2018 Parag Nemade <pnemade AT redhat DOT com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * */

#include <gio/gio.h>
#include <locale.h>

int main (int argc, char *argv[])
{
	const gchar *packages[16];
	GDBusProxy *proxym = NULL;
	GDBusProxy *proxyq = NULL;
	GError *error = NULL;
	guint32 xid = 0;
	GVariant *retvalm = NULL;
	GVariant *retvalq = NULL;
	gchar **current_locale;
	gchar *mlocale;
	gchar **lang;
	gboolean pkg_installed;
	gint element=0;
	gchar pkgname[16];
	gchar *whitelist[5] = {"en_GB","pt_BR", "zh_CN", "zh_TW"};

	proxyq = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,
						G_DBUS_PROXY_FLAGS_NONE, NULL,
						"org.freedesktop.PackageKit",
						"/org/freedesktop/PackageKit",
						"org.freedesktop.PackageKit.Query",
						NULL, &error);
	if (proxyq == NULL) {
		g_warning ("failed: %s", error->message);
		g_error_free (error);
		goto outq;
	}

	proxym = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,
					       G_DBUS_PROXY_FLAGS_NONE, NULL,
					       "org.freedesktop.PackageKit",
					       "/org/freedesktop/PackageKit",
					       "org.freedesktop.PackageKit.Modify",
					       NULL, &error);
	if (proxym == NULL) {
		g_warning ("failed: %s", error->message);
		g_error_free (error);
		goto outm;
	}

	current_locale = g_strsplit (setlocale(LC_ALL, ""),".",2);
	mlocale=current_locale[0];

	for(element=0;element< 4;element++)
	{
		if (g_strcmp0(current_locale[0],whitelist[element]) != 0)
		{
			lang = g_strsplit (current_locale[0],"_",2);
			mlocale=lang[0];
		}
		else
		{
			mlocale=current_locale[0];
			break;
		}
	}

	g_snprintf(pkgname,16,"langpacks-%s",mlocale);

	packages[0]=pkgname;
	packages[1]= NULL;
	retvalq = g_dbus_proxy_call_sync (proxyq,
					"IsInstalled",
					g_variant_new ("(ss)",
					pkgname,
					""),
					G_DBUS_CALL_FLAGS_NONE,
					-1,
					NULL,
					&error);
	if (retvalq == NULL) {
		g_warning ("failed: %s", error->message);
		g_error_free (error);
		goto outq;
	}
	else
	{
		g_variant_get(retvalq ,"(b)",&pkg_installed);
		if (pkg_installed == 0)
		{
			retvalm = g_dbus_proxy_call_sync (proxym,
							"InstallPackageNames",
							g_variant_new ("(u^a&ss)",
							xid,
							packages,
							"hide-finished"),
				 			G_DBUS_CALL_FLAGS_NONE,
				 			-1,
				 			NULL,
				 			&error);
			if (retvalm == NULL) {
				g_warning ("failed: %s", error->message);
				g_error_free (error);
				goto outm;
			}
		}
	}

outq:
	if (proxyq != NULL)
		g_object_unref (proxyq);

outm:
	if (proxym != NULL)
		g_object_unref (proxym);

	return 0;
}

